==> apache-camel-4.14.3-src.zip: apache-camel-4.14.3/components/camel-telemetry/src/test/java/org/apache/camel/telemetry/decorators/TimerSpanDecoratorTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.telemetry.decorators;

import org.apache.camel.Exchange;
import org.apache.camel.telemetry.SpanDecorator;
import org.junit.jupiter.api.Test;
import org.mockito.Mockito;

import static org.junit.jupiter.api.Assertions.assertEquals;

public class TimerSpanDecoratorTest {

    private static final String TEST_NAME = "TestName";

    @Test
    public void testGetOperationName() {
        Exchange exchange = Mockito.mock(Exchange.class);

        Mockito.when(exchange.getProperty(Exchange.TIMER_NAME, String.class)).thenReturn(TEST_NAME);

        SpanDecorator decorator = new TimerSpanDecorator() {
            @Override
            public String getComponent() {
                return null;
            }
        };

        assertEquals(TEST_NAME, decorator.getOperationName(exchange, null));
    }

}

==> apache-camel-4.15.0-src.zip: apache-camel-4.15.0/components/camel-telemetry/src/test/java/org/apache/camel/telemetry/decorators/TimerSpanDecoratorTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.telemetry.decorators;

import org.apache.camel.Exchange;
import org.apache.camel.telemetry.SpanDecorator;
import org.junit.jupiter.api.Test;
import org.mockito.Mockito;

import static org.junit.jupiter.api.Assertions.assertEquals;

public class TimerSpanDecoratorTest {

    private static final String TEST_NAME = "TestName";

    @Test
    public void testGetOperationName() {
        Exchange exchange = Mockito.mock(Exchange.class);

        Mockito.when(exchange.getProperty(Exchange.TIMER_NAME)).thenReturn(TEST_NAME);

        SpanDecorator decorator = new TimerSpanDecorator() {
            @Override
            public String getComponent() {
                return null;
            }
        };

        assertEquals(TEST_NAME, decorator.getOperationName(exchange, null));
    }

}
